@@ -7,8 +7,9 @@ from .types import (
     VaccinationByRegionRow,
     VaccinationByManufacturerRow,
     VaccinationDose,
-    VaccinationByAgeGroup,
     VaccinationMunShare,
+    VaccinationAgeGroupByRegionOnDayDose,
+    VaccinationAgeGroupByRegionOnDay,
 )
 
 
@@ -315,8 +316,8 @@ def _parse_vaccinations_by_municipalities_share(data) -> "list[VaccinationMunSha
     parsed_data = []
 
     for el in resp:
-        name, share2, population, share1 = el["C"]
-        print(name, share2, population, share1, sep="\t")
+        name, share1, population, share2 = el["C"]
+        print(name, share1, population, share2, sep="\t")
         dose1 = round(int(population) * float(share1))
         dose2 = round(int(population) * float(share2))
         parsed_data.append(
@@ -331,3 +332,83 @@ def _parse_vaccinations_by_municipalities_share(data) -> "list[VaccinationMunSha
         )
 
     return parsed_data
+
+
+def _parse_vaccinations_age_group_by_region_on_day(
+    data,
+) -> "list[VaccinationAgeGroupByRegionOnDay]":
+    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
+        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
+            "odata.error"
+        ]
+        print(error)
+        raise Exception("Something went wrong!")
+
+    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
+
+    def parse_resp_data(region, item):
+        if len(item) == 4:
+            return VaccinationAgeGroupByRegionOnDayDose(
+                region=region,
+                total_share=float(item[0]),
+                group_share=float(item[1]),
+                total_count=item[2],
+                group_count=item[3],
+            )
+        if len(item) == 3:
+            print(3, item)
+            return VaccinationAgeGroupByRegionOnDayDose(
+                region=region,
+                total_share=float(item[0]),
+                group_share=float(item[1]),
+                total_count=item[2],
+            )
+        if len(item) == 2:
+            return VaccinationAgeGroupByRegionOnDayDose(
+                region=region,
+                total_share=float(item[0]),
+                total_count=item[1],
+            )
+        raise Exception('Unknown item length!')
+
+    parsed_data = []
+    for el in resp:
+        region = el["G0"]
+        first_dose = parse_resp_data(region, el["X"][0]["C"])
+        second_dose = parse_resp_data(region, el["X"][1]["C"])
+        parsed_data.append(
+            VaccinationAgeGroupByRegionOnDay(
+                region=region, dose1=first_dose, dose2=second_dose
+            )
+        )
+
+    return parsed_data
+
+
+def _parse_vaccinations_by_manufacturer_supplied_used(
+    data,
+) -> "list[VaccineSupplyUsage]":
+    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
+        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
+            "odata.error"
+        ]
+        print(error)
+        raise Exception("Something went wrong!")
+
+    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
+
+    parsed_data = []
+    item = None
+    for el in resp:
+        C = el["C"]
+        date = parse_date(C[0])
+        if len(C) == 2:
+            item = VaccineSupplyUsage(date=date, supplied=int(C[1]), used=0)
+            parsed_data.append(item)
+        elif len(C) == 3:
+            item = VaccineSupplyUsage(date=date, supplied=int(C[2]), used=int(C[1]))
+            parsed_data.append(item)
+        else:
+            raise Exception("Unknown [C] length")
+
+    return parsed_data
