@@ -52,12 +52,6 @@ class VaccinationDose:
     dose: int
 
 
-@dataclass
-class VaccinationByAgeGroup:
-    dose1: "list[VaccinationDose]"
-    dose2: "list[VaccinationDose]"
-
-
 @dataclass
 class VaccinationMunShare:
     name: str
@@ -65,4 +59,20 @@ class VaccinationMunShare:
     share1: float
     dose2: int
     share2: float
-    population: int
\ No newline at end of file
+    population: int
+
+
+@dataclass
+class VaccinationAgeGroupByRegionOnDayDose:
+    region: str
+    total_count: int = 0
+    group_count: int = 0
+    total_share: float = 0.0
+    group_share: float = 0.0
+
+
+@dataclass
+class VaccinationAgeGroupByRegionOnDay:
+    region: str
+    dose1: VaccinationAgeGroupByRegionOnDayDose
+    dose2: VaccinationAgeGroupByRegionOnDayDose
\ No newline at end of file
